@@ -1,7 +1,7 @@
 """
 Type annotations for cloud9 service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloud9/literals/)
 
 Usage::
 
@@ -30,8 +30,11 @@ __all__ = (
     "ManagedCredentialsStatusType",
     "MemberPermissionsType",
     "PermissionsType",
+    "Cloud9ServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -61,6 +64,7 @@ ManagedCredentialsStatusType = Literal[
 ]
 MemberPermissionsType = Literal["read-only", "read-write"]
 PermissionsType = Literal["owner", "read-only", "read-write"]
+Cloud9ServiceName = Literal["cloud9"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -94,6 +98,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
     "cloudcontrol",
@@ -348,4 +353,39 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal["describe_environment_memberships", "list_environments"]
+RegionName = Literal[
+    "af-south-1",
+    "ap-east-1",
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-northeast-3",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-south-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "me-south-1",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
